// =====================================================================================
// Includes
// =====================================================================================

#include "global.h"

#include "LED_display.h"
#include "Key_Panel.h"
#include "LED_row.h"
#include "ISR.h"

// =====================================================================================
// Unterprogramme
// =====================================================================================

void LEDs_init(void)
{
	// Ports initialisieren
	DDRB |= (1<<PB2) | (1<<PB3);
	PORTB |= (1<<PB2) | (1<<PB3);
}

void LED1_on(void)
{
	PORTB &= ~(1<<PB2);
}

void LED2_on(void)
{
	PORTB &= ~(1<<PB3);
}

void LED1_off(void)
{
	PORTB |= (1<<PB2);
}

void LED2_off(void)
{
	PORTB |= (1<<PB3);
}

void LED1_switch(void)
{
	PORTB ^= (1<<PB2);
}

void LED2_switch(void)
{
	PORTB ^= (1<<PB3);
}

void LED_row_init(void)
{
	// Ports initialisieren
	DDRB |= (1<<PB4) | (1<<PB5) | (1<<PB7);
	PORTB |= (1<<PB4);
	
	// SPI initialisieren
	SPCR = (1<<SPE) | (1<<MSTR) | (1<<SPI2X) | (1<<SPR1) | (1<<SPR0);
}

void LED_row_output(uint16_t output)
{
	// Output per SPI in Schieberegister bertragen
	SPDR = output/256;
	while (!(SPSR & (1<<SPIF)));
	SPDR = output;
	while (!(SPSR & (1<<SPIF)));

	// Daten von Schieberegister in Latches
	PORTB &= ~(1<<PB4);
	PORTB |= (1<<PB4);
}

void LED_row_off(void)
{
	LED_row_output(0xFFFF);
}

void LED_row_segment_on(uint8_t segment)
{
	LED_row_output(~(1<<(16-segment)));
}