#ifndef GLOBAL_H_
#define GLOBAL_H_

// =====================================================================================
// Include C Libriaries
// =====================================================================================

#define F_CPU 8000000UL

#include <stdio.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <stdint.h>
#include <avr/io.h>
#include <util/delay.h>

// =====================================================================================
// Globale Variablen
// =====================================================================================

// Tastenfeld
volatile uint16_t key_state;
volatile uint16_t key_press;

// Definition der Segmente
#define SEG_O (1<<PD7)		// Segment oben
#define SEG_OR (1<<PD6)		// Segment oben rechts
#define SEG_UR (1<<PD5)		// Segment unten rechts
#define SEG_U (1<<PD4)		// Segment unten
#define SEG_UL (1<<PD3)		// Segment unten links
#define SEG_OL (1<<PD2)		// Segment oben links
#define SEG_M (1<<PD1)		// Segment Mitte
#define SEG_DOT (1<<PD0)	// Segment Punkt

// Tabelle in Programmspeicher fuer LED-Segmente pro Ziffer
static const PROGMEM uint8_t segmente_array[] =
{
{SEG_UL | SEG_OL | SEG_O | SEG_OR | SEG_UR | SEG_U },			// Ziffer 0
{SEG_OR | SEG_UR},												// Ziffer 1
{SEG_UL | SEG_O | SEG_OR | SEG_U | SEG_M},						// Ziffer 2
{SEG_O | SEG_OR | SEG_UR | SEG_U | SEG_M},						// Ziffer 3
{SEG_OL | SEG_OR | SEG_UR | SEG_M},								// Ziffer 4
{SEG_OL | SEG_O | SEG_UR | SEG_U | SEG_M},						// Ziffer 5
{SEG_UL | SEG_OL | SEG_O | SEG_UR | SEG_U | SEG_M},				// Ziffer 6
{SEG_O | SEG_OR | SEG_UR},										// Ziffer 7
{SEG_UL | SEG_OL | SEG_O | SEG_OR | SEG_UR | SEG_U | SEG_M},	// Ziffer 8
{SEG_OL | SEG_O | SEG_OR | SEG_UR | SEG_U | SEG_M},				// Ziffer 9
{0},															// aus
};

// Definition der Ziffern
#define DIG_1 (1<<PC3)		// Ziffer 1
#define DIG_2 (1<<PC2)		// Ziffer 2
#define DIG_3 (1<<PC1)		// Ziffer 3
#define DIG_4 (1<<PC0)		// Ziffer 4

// LED Display
static volatile uint8_t digit[4];					// Ziffern fr Anzeige
static volatile uint8_t display_on=0;		// Flag, ob Anzeige eingeschalten
static volatile uint8_t aktStelle=0;		// aktuelle Ziffer im Multiplexing


#endif